@@ -40,7 +40,7 @@ def create_excel_xlsx(path, sheet_name):
 
 def write_excel_xlsx_append(path,name, value,sheet_name = 'Sheet1', truncate_sheet=False):
     """
-    :param path: ./demo/test.xlsx
+    :param path: ./demo/sycm.xlsx
     :param value: [[],[]]
     :param truncate_sheet:truncate_sheet为True，覆盖原表中的数据
     :return:
